/*
    RPGFight v0.00.00--RPG Battle Simulator
    idlenobr.c, idlenobr.89z--A utility for saving battery power in a
        TI-BASIC program during idle periods
    Copyright (C) 2007 Travis Evans

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#define USE_TI89

#define ENABLE_ERROR_RETURN

#include <args.h>
#include <error.h>
#include <estack.h>
#include <kbd.h>
#include <system.h>
#include <statline.h>

/* This program delays for a certain length of time while calling
   idle().  This program is primarily intended to allow TI-BASIC
   programs to conserve battery power. */

/* Takes one argument from a TI-BASIC program: The length of time
   (in approx. 50-millisecond units) to delay.  This program cannot be
   broken out of by pressing a key.  It will force the user to wait
   until the delay is over. */
void _main(void) {
    ESI argptr = top_estack;
    unsigned long delayTime;

    // Check argument (must be positive integer only)
    if (GetArgType(argptr) == POSINT_TAG) {
        delayTime = GetIntArg(argptr);
    } else {
        ER_throw(ER_ARGUMENT);
    }
    /* Only allow arguments from .05 to 10 seconds to prevent
       accidentally locking up the calculator for excessive periods of
       time by passing a bad argument */
    if (delayTime <= 0 || delayTime > 200)
        ER_throw(ER_ARGUMENT);

    OSFreeTimer(USER_TIMER);
    OSRegisterTimer(USER_TIMER, delayTime);

    ST_busy(ST_NORMAL);
    while (!OSTimerExpired(USER_TIMER))
        idle();
    ST_busy(ST_BUSY);

    OSFreeTimer(USER_TIMER);

}
